# BuildBuildLog

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**apiversion** | **str** | BuildLog api version | [optional]
**kind** | **str** | Type of the log  | [optional]
**log** | **str** | A full build or installation log that was output during image build | [optional]
**metadata** | **str** |  | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

